@@ -18,6 +18,9 @@
 
 #include "../config.h"
 #include <sys/types.h>
+#ifdef HAVE_SYS_SYSLIMITS_H
+#include <sys/syslimits.h>
+#endif
 #include <assert.h>
 #include <ctype.h>
 #include <stdio.h>
